@@ -67,7 +67,7 @@ Gets the count of sizes in this series.
 
 =head1 AUTHOR
 
-Cory 'G' Watson <gphat@cpan.org>
+Cory G Watson <gphat@cpan.org>
 
 =head1 LICENSE
 
